@@ -74,8 +74,6 @@
 #' limit the number of variables created.
 #' 
 #' @seealso [step_untokenize()]
-#' @importFrom recipes add_step step terms_select sel2char ellipse_check 
-#' @importFrom recipes check_type rand_id
 step_tokenfilter <-
   function(recipe,
            ...,
@@ -93,8 +91,9 @@ step_tokenfilter <-
 
     if (percentage && (max_times > 1 | max_times < 0 |
                       min_times > 1 | min_times < 0))
-      stop("`max_times` and `min_times` should be in the interval [0, 1].",
-           call. = FALSE)
+      rlang::abort(
+        "`max_times` and `min_times` should be in the interval [0, 1]."
+        )
 
     add_step(
       recipe,
@@ -166,9 +165,6 @@ prep.step_tokenfilter <- function(x, training, info = NULL, ...) {
 }
 
 #' @export
-#' @importFrom tibble as_tibble tibble
-#' @importFrom recipes bake prep
-#' @importFrom purrr map
 bake.step_tokenfilter <- function(object, new_data, ...) {
   col_names <- object$columns
   # for backward compat
@@ -197,15 +193,15 @@ tokenfilter_fun <- function(data, max_times, min_times, max_features,
     names(sort(tf[ids], decreasing = TRUE))
   } else {
     if (max_features > sum(ids)) {
-      warning(paste0("max_features was set to '", max_features,
-                     "', but only ", sum(ids), " was available and selected."))
+      rlang::warn(paste0("max_features was set to '", max_features,
+                         "', but only ", sum(ids), 
+                         " was available and selected."))
       max_features <- sum(ids)
     }
     names(sort(tf[ids], decreasing = TRUE)[seq_len(max_features)])
   }
 }
 
-#' @importFrom recipes printer
 #' @export
 print.step_tokenfilter <-
   function(x, width = max(20, options()$width - 30), ...) {
@@ -216,7 +212,6 @@ print.step_tokenfilter <-
 
 #' @rdname step_tokenfilter
 #' @param x A `step_tokenfilter` object.
-#' @importFrom rlang na_int
 #' @export
 tidy.step_tokenfilter <- function(x, ...) {
   if (is_trained(x)) {
