@@ -22,23 +22,23 @@ test_that("step_tfidf works as intended", {
   rec_answer <- unname(juice(obj))
   
   manual_answer <- unname(
-    tibble(am =       c(0 / 8, 0 / 6, 0 / 8, 1 / 8) * log(4 / (1 + 1)),
-           and =      c(0 / 8, 0 / 6, 1 / 8, 0 / 8) * log(4 / (1 + 1)),
-           anywhere = c(0 / 8, 1 / 6, 0 / 8, 0 / 8) * log(4 / (1 + 1)),
-           do =       c(0 / 8, 0 / 6, 0 / 8, 1 / 8) * log(4 / (1 + 1)),
-           eat =      c(1 / 8, 1 / 6, 1 / 8, 0 / 8) * log(4 / (3 + 1)),
-           eggs =     c(0 / 8, 0 / 6, 1 / 8, 0 / 8) * log(4 / (1 + 1)),
-           green =    c(0 / 8, 0 / 6, 1 / 8, 0 / 8) * log(4 / (1 + 1)),
-           ham =      c(0 / 8, 0 / 6, 1 / 8, 0 / 8) * log(4 / (1 + 1)),
-           here =     c(1 / 8, 0 / 6, 0 / 8, 0 / 8) * log(4 / (1 + 1)),
-           i =        c(1 / 8, 1 / 6, 1 / 8, 2 / 8) * log(4 / (4 + 1)),
-           like =     c(0 / 8, 0 / 6, 0 / 8, 1 / 8) * log(4 / (1 + 1)),
-           not =      c(1 / 8, 1 / 6, 1 / 8, 1 / 8) * log(4 / (4 + 1)),
-           or =       c(1 / 8, 0 / 6, 0 / 8, 0 / 8) * log(4 / (1 + 1)),
-           sam =      c(0 / 8, 0 / 6, 0 / 8, 1 / 8) * log(4 / (1 + 1)), 
-           them =     c(1 / 8, 1 / 6, 0 / 8, 1 / 8) * log(4 / (3 + 1)),
-           there =    c(1 / 8, 0 / 6, 0 / 8, 0 / 8) * log(4 / (1 + 1)),
-           would =    c(1 / 8, 1 / 6, 1 / 8, 0 / 8) * log(4 / (3 + 1)))
+    tibble(am =       c(0 / 8, 0 / 6, 0 / 8, 1 / 8) * log(1 + 4 / 1),
+           and =      c(0 / 8, 0 / 6, 1 / 8, 0 / 8) * log(1 + 4 / 1),
+           anywhere = c(0 / 8, 1 / 6, 0 / 8, 0 / 8) * log(1 + 4 / 1),
+           do =       c(0 / 8, 0 / 6, 0 / 8, 1 / 8) * log(1 + 4 / 1),
+           eat =      c(1 / 8, 1 / 6, 1 / 8, 0 / 8) * log(1 + 4 / 3),
+           eggs =     c(0 / 8, 0 / 6, 1 / 8, 0 / 8) * log(1 + 4 / 1),
+           green =    c(0 / 8, 0 / 6, 1 / 8, 0 / 8) * log(1 + 4 / 1),
+           ham =      c(0 / 8, 0 / 6, 1 / 8, 0 / 8) * log(1 + 4 / 1),
+           here =     c(1 / 8, 0 / 6, 0 / 8, 0 / 8) * log(1 + 4 / 1),
+           i =        c(1 / 8, 1 / 6, 1 / 8, 2 / 8) * log(1 + 4 / 4),
+           like =     c(0 / 8, 0 / 6, 0 / 8, 1 / 8) * log(1 + 4 / 1),
+           not =      c(1 / 8, 1 / 6, 1 / 8, 1 / 8) * log(1 + 4 / 4),
+           or =       c(1 / 8, 0 / 6, 0 / 8, 0 / 8) * log(1 + 4 / 1),
+           sam =      c(0 / 8, 0 / 6, 0 / 8, 1 / 8) * log(1 + 4 / 1), 
+           them =     c(1 / 8, 1 / 6, 0 / 8, 1 / 8) * log(1 + 4 / 3),
+           there =    c(1 / 8, 0 / 6, 0 / 8, 0 / 8) * log(1 + 4 / 1),
+           would =    c(1 / 8, 1 / 6, 1 / 8, 0 / 8) * log(1 + 4 / 3))
     )
   
   expect_equal(
